module.exports = (api, opts, rootOptions) => {
  const utils = require('./utils')(api)

  api.extendPackage({
    dependencies: {
      'element-plus': '^1.0.2-beta.28'
    }
  })

  const type = utils.getMain()
  api.injectImports(type, `import installElementPlus from './plugins/element'`)

  if (type === 'src/main.ts') {
    api.render({
      './src/plugins/element.ts': './templates/src/plugins/element.ts',
      './src/App.vue': './templates/src/App.vue'
    })
  } else {
    api.render({
      './src/plugins/element.js': './templates/src/plugins/element.js',
      './src/App.vue': './templates/src/App.vue'
    })
  }
  

  if (opts.import === 'partial') {
    api.extendPackage({
      devDependencies: {
        'babel-plugin-component': '^1.1.1'
      }
    })
  } else if (opts.customTheme) {
    api.render({
      './src/element-variables.scss': './templates/src/element-variables.scss'
    })
    api.extendPackage({
      devDependencies: {
        'sass-loader': '^10.0.4',
        'sass': '^1.27.0'
      }
    })
  }

  api.afterInvoke(() => {
    const { EOL } = require('os')
    const fs = require('fs')
    const contentMain = fs.readFileSync(api.resolve(api.entryFile), { encoding: 'utf-8' })
   
    const lines = contentMain.split(/\r?\n/g)
    // 这里有个坑 就是生成的项目可能用单引号 也可能是双引号
    // const renderIndex = lines.findIndex(line => line.match(/createApp\(App\)(\.use\(\w*\))*\.mount\('#app'\)/))
    // const renderIndex3 = lines.findIndex(line => line.match(/createApp\(App\)(\.use\(\w*\))*\.mount\("#app"\)/))
    const renderIndex = lines.findIndex(line => line.match(/^createApp/))
    // createApp(App).use(store).use(router).mount("#app");
    if (renderIndex > 0) {
      // 此时是createApp(App).use(store).use(router).mount("#app")的格式
      const renderContent = lines[renderIndex]
      lines[renderIndex] = `const app = createApp(App)`
      lines[renderIndex + 1] = `installElementPlus(app)`
      lines[renderIndex + 2]  = renderContent.replace('createApp\(App\)','app')

      fs.writeFileSync(api.resolve(api.entryFile), lines.join(EOL), { encoding: 'utf-8' })
    } else {
      // 此时是const app = createApp(App)格式 直接在下面追加installXX格式
      fs.appendFile(api.resolve(api.entryFile), '\ninstallElementPlus(app)', (err) => {
        if (err) throw err;
        console.log('数据已被追加到文件');
      })
    }
    
    // shims-vue.d.ts 声明 element-plus 否则ts会报红
    fs.appendFile(api.resolve('src/shims-vue.d.ts'), '\ndeclare module "element-plus"', (err) => {
      if (err) throw err;
      console.log('数据已被追加到文件');
    })
  })

  api.onCreateComplete(() => {
    if (opts.import === 'partial') {
      utils.updateBabelConfig(cfg => {
        const pluginComponent = ['component', {
          'libraryName': 'element-plus',
          'styleLibraryName': 'theme-chalk'
        }]
        cfg.plugins = cfg.plugins || []
        cfg.plugins.push(pluginComponent)
        return cfg
      })
    }
  })
}
